@@ -12,7 +12,7 @@
  See the License for the specific language governing permissions and
  limitations under the License.
 
- Copyright (C) 2013 CERN
+ Copyright (C) CERN 2013-2021
 """
 
 from messaging.message import Message
@@ -22,6 +22,9 @@ import time
 
 
 class MyListener(MessageListener):
+    """
+    Example listener class
+    """
     def __init__(self):
         self.uuid = None
         self.done = False
@@ -54,11 +57,12 @@ def stomppy_test():
     conn.send(msg.body, **msg.header)
     print("sending message %s" % msg)
 
-    t1 = time.time()
-    while not listener.done and (time.time() - t1 < 2):
+    start = time.time()
+    while not listener.done and (time.time() - start < 2):
         time.sleep(0.1)
     conn.disconnect()
     print("...stomppy example ok")
 
+
 if __name__ == "__main__":
     stomppy_test()
