@@ -12,14 +12,14 @@ http://pypi.python.org/pypi/messaging/
 
 An Perl implementation of the same abstractions and queue algorithms
 is available at the following page:
-http://search.cpan.org/~lcons/Messaging-Message/
+http://search.cpan.org/dist/Messaging-Message/
 
-Copyright (C) 2013 CERN
+Copyright (C) CERN 2013-2021
 """
+
 AUTHOR = "Massimo Paladin <massimo.paladin@gmail.com>"
-COPYRIGHT = "Copyright (C) 2013 CERN"
-VERSION = "1.0"
-DATE = "28 Feb 2013"
+VERSION = "1.2"
+DATE = "3 Nov 2021"
 __author__ = AUTHOR
 __version__ = VERSION
 __date__ = DATE
