@@ -15,11 +15,11 @@
 
 from messaging.generator import Generator
 import messaging.generator as generator
-import re
 import unittest
 
 
 class MessageTest(unittest.TestCase):
+    """ test messaging.generator """
 
     def setUp(self):
         """ setup the test environment """
@@ -28,56 +28,62 @@ class MessageTest(unittest.TestCase):
         """ restore the test environment """
 
     def test_rndint(self):
+        """ test generator.rndint() """
         print("checking integers randomization")
         for index in range(1000):
             integer = int(generator.rndint(index))
-            self.assert_(integer >= 0 and integer <= index * 2,
-                         "size not expected")
+            self.assertTrue(integer >= 0 and integer <= index * 2,
+                            "size not expected")
         print("...integers randomization ok")
 
     def test_rndbin(self):
+        """ test generator.rndbin() """
         print("checking binary string creation")
         for index in range(1000):
-            bin = generator.rndbin(index)
-            self.assert_(len(bin) == index, "size not expected")
+            binary = generator.rndbin(index)
+            self.assertTrue(len(binary) == index, "size not expected")
         print("...binary string creation ok")
 
     def test_rndb64(self):
+        """ test generator.rndb64() """
         print("checking base64 string creation")
         for index in range(1000):
             b64 = generator.rndb64(index)
-            self.assert_(len(b64) == index, "size not expected")
+            self.assertTrue(len(b64) == index, "size not expected")
         print("...base64 string creation ok")
 
     def test_rndstr(self):
+        """ test generator.rndstr() """
         print("checking string creation")
         for index in range(1000):
             string = generator.rndstr(index)
-            self.assert_(len(string) == index, "size not expected")
+            self.assertTrue(len(string) == index, "size not expected")
         print("...string creation ok")
 
     def test_generator(self):
+        """ test message generation """
         print("checking message generation")
-        types = ['index', 'text', 'binary', 'base64']
-        for type in types:
-            for size in [0, 1024, 10240, 102400]:
+        bctypes = ['index', 'text', 'binary', 'base64']
+        for bctype in bctypes:
+            for bsize in [0, 1024, 10240, 102400]:
                 for header_count in [1, 10]:
-                    gen = Generator(body_content=type,
-                                    body_size=size,
+                    gen = Generator(body_content=bctype,
+                                    body_size=bsize,
                                     header_count=header_count)
-                    for iter in range(5):
+                    for i in range(5):
                         msg = gen.message()
-                        if type != 'index':
-                            self.assertEqual(len(msg.body), size,
+                        if bctype != 'index':
+                            self.assertEqual(len(msg.body), bsize,
                                              "body size not expected")
                         else:
-                            if size == 0:
+                            if bsize == 0:
                                 cor = 0
                             else:
-                                cor = len("%d" % iter)
+                                cor = len("%d" % i)
                             self.assertEqual(len(msg.body), cor,
                                              "body size not expected")
         print("...message generation ok")
 
+
 if __name__ == "__main__":
     unittest.main()
